@@ -671,6 +671,63 @@ def decrypt(s, passphrase, curve='secp160r1', mac_bytes=10):
     privkey = curve.passphrase_to_privkey(passphrase)
     return privkey.decrypt(s, mac_bytes)
 
+def encrypt_file(in_path_or_file, out_path_or_file, pk, pk_format=SER_COMPACT,
+                 mac_bytes=10, chunk_size=4096):
+    """ Encrypts `in_file' to `out_file' for pubkey `pk' """
+    close_in, close_out = False, False
+    in_file, out_file = in_path_or_file, out_path_or_file
+    try:
+        if isinstance(in_path_or_file, basestring):
+            in_file = open(in_path_or_file, 'rb')
+            close_in = True
+        if isinstance(out_path_or_file, basestring):
+            out_file = open(out_path_or_file, 'wb')
+            close_out = True
+        _encrypt_file(in_file, out_file, pk, pk_format, mac_bytes, chunk_size)
+    finally:
+        if close_out: out_file.close()
+        if close_in: in_file.close()
+
+def decrypt_file(in_path_or_file, out_path_or_file, passphrase,
+                 curve='secp160r1', mac_bytes=10, chunk_size=4096):
+    """ Decrypts `in_file' to `out_file' with passphrase `passphrase' """
+    close_in, close_out = False, False
+    in_file, out_file = in_path_or_file, out_path_or_file
+    try:
+        if isinstance(in_path_or_file, basestring):
+            in_file = open(in_path_or_file, 'rb')
+            close_in = True
+        if isinstance(out_path_or_file, basestring):
+            out_file = open(out_path_or_file, 'wb')
+            close_out = True
+        _decrypt_file(in_file, out_file, passphrase, curve, mac_bytes,
+                      chunk_size)
+    finally:
+        if close_out: out_file.close()
+        if close_in: in_file.close()
+
+def _encrypt_file(in_file, out_file, pk, pk_format=SER_COMPACT,
+                 mac_bytes=10, chunk_size=4096):
+    curve = Curve.by_pk_len(len(pk))
+    p = curve.pubkey_from_string(pk, pk_format)
+    with p.encrypt_to(out_file, mac_bytes) as encrypted_out:
+        while True:
+            buff = in_file.read(chunk_size)
+            if not buff:
+                break
+            encrypted_out.write(buff)
+
+def _decrypt_file(in_file, out_file, passphrase, curve='secp160r1',
+                 mac_bytes=10, chunk_size=4096):
+    curve = Curve.by_name(curve)
+    privkey = curve.passphrase_to_privkey(passphrase)
+    with privkey.decrypt_from(in_file, mac_bytes) as decrypted_in:
+        while True:
+            buff = decrypted_in.read(chunk_size)
+            if not buff:
+                break
+            out_file.write(buff)
+
 def verify(s, sig, pk, sig_format=SER_COMPACT, pk_format=SER_COMPACT):
     """ Verifies that `sig' is a signature of pubkey `pk' for the
         message `s'. """
